@@ -20,10 +20,10 @@ public:
     [[nodiscard]] bool exportData(const QString &language, const QString &fileName, QString &errorMessage, const QString &writablePath) override;
 
 private:
-    TEXTAUTOCORRECTIONCORE_NO_EXPORT void exportDocumentList();
-    TEXTAUTOCORRECTIONCORE_NO_EXPORT void exportSentenceExceptList();
-    TEXTAUTOCORRECTIONCORE_NO_EXPORT void exportWordExceptList();
-    TEXTAUTOCORRECTIONCORE_NO_EXPORT void exportManifest();
+    [[nodiscard]] bool exportDocumentList();
+    [[nodiscard]] bool exportSentenceExceptList();
+    [[nodiscard]] bool exportWordExceptList();
+    [[nodiscard]] bool exportManifest();
     KZip *mZip = nullptr;
 };
 }
