@@ -9,6 +9,7 @@
 #include <QCoreApplication>
 #include <QRegularExpression>
 #include <QStandardPaths>
+#include <QUuid>
 using namespace TextAutoGenerateText;
 using namespace Qt::Literals::StringLiterals;
 
@@ -22,3 +23,8 @@ QStringList TextAutoGenerateTextUtils::instancesList(KConfig *config)
     static const QRegularExpression regularExpression(u"^Instance #\\d+$"_s);
     return config->groupList().filter(regularExpression);
 }
+
+QByteArray TextAutoGenerateTextUtils::generateUUid()
+{
+    return QUuid::createUuid().toByteArray(QUuid::Id128);
+}
