@@ -14,7 +14,7 @@ GenericNetworkServerInfo::GenericNetworkServerInfo() = default;
 
 GenericNetworkServerInfo::~GenericNetworkServerInfo() = default;
 
-QString GenericNetworkServerInfo::translatedName(GenericNetworkManager::PluginNetworkType type) const
+QString GenericNetworkServerInfo::translatedName(GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -38,11 +38,13 @@ QString GenericNetworkServerInfo::translatedName(GenericNetworkManager::PluginNe
         return i18n("Anthropic");
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return i18n("Kimi (Moonshot AI)");
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
+        return i18n("Grok (X.ai)");
     }
     return {};
 }
 
-QString GenericNetworkServerInfo::chatCompletionPath(GenericNetworkManager::PluginNetworkType type) const
+QString GenericNetworkServerInfo::chatCompletionPath(GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -57,12 +59,13 @@ QString GenericNetworkServerInfo::chatCompletionPath(GenericNetworkManager::Plug
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
     case GenericNetworkManager::PluginNetworkType::KimiAI:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return u"chat/completions"_s;
     }
     return {};
 }
 
-QString GenericNetworkServerInfo::webSite(GenericNetworkManager::PluginNetworkType type) const
+QString GenericNetworkServerInfo::webSite(GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -86,11 +89,13 @@ QString GenericNetworkServerInfo::webSite(GenericNetworkManager::PluginNetworkTy
         return u"https://www.anthropic.com/"_s;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"https://www.moonshot.ai/"_s;
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
+        return u"https://api.x.ai/"_s;
     }
     return {};
 }
 
-QString GenericNetworkServerInfo::apiUrl(GenericNetworkManager::PluginNetworkType type) const
+QString GenericNetworkServerInfo::apiUrl(GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -114,11 +119,13 @@ QString GenericNetworkServerInfo::apiUrl(GenericNetworkManager::PluginNetworkTyp
         return u"https://api.anthropic.com/v1/"_s;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"https://api.moonshot.ai/v1/"_s;
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
+        return u"https://api.x.ai/v1/"_s;
     }
     return {};
 }
 
-QString GenericNetworkServerInfo::description(GenericNetworkManager::PluginNetworkType type) const
+QString GenericNetworkServerInfo::description(GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -129,6 +136,7 @@ QString GenericNetworkServerInfo::description(GenericNetworkManager::PluginNetwo
     case GenericNetworkManager::PluginNetworkType::OpenAI:
     case GenericNetworkManager::PluginNetworkType::VeniceAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return {};
     case GenericNetworkManager::PluginNetworkType::GroqAI:
         return i18n("Groq AI");
@@ -144,7 +152,7 @@ QString GenericNetworkServerInfo::description(GenericNetworkManager::PluginNetwo
     return {};
 }
 
-QString GenericNetworkServerInfo::pluginName(GenericNetworkManager::PluginNetworkType type) const
+QString GenericNetworkServerInfo::pluginName(GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -168,11 +176,13 @@ QString GenericNetworkServerInfo::pluginName(GenericNetworkManager::PluginNetwor
         return u"anthropic"_s;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"kimiai"_s;
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
+        return u"grokai"_s;
     }
     return {};
 }
 
-GenericNetworkManager::PluginNetworkType GenericNetworkServerInfo::pluginNetworkTypeFromString(const QString &str) const
+GenericNetworkManager::PluginNetworkType GenericNetworkServerInfo::pluginNetworkTypeFromString(const QString &str)
 {
     if (str == QLatin1StringView("mistralai")) {
         return GenericNetworkManager::PluginNetworkType::MistralAI;
@@ -192,13 +202,15 @@ GenericNetworkManager::PluginNetworkType GenericNetworkServerInfo::pluginNetwork
         return GenericNetworkManager::PluginNetworkType::Anthropic;
     } else if (str == QLatin1StringView("kimiai")) {
         return GenericNetworkManager::PluginNetworkType::KimiAI;
+    } else if (str == QLatin1StringView("grokai")) {
+        return GenericNetworkManager::PluginNetworkType::GrokAI;
     } else {
         qCWarning(AUTOGENERATETEXT_GENERICNETWORK_LOG) << "PluginNetworkType is unknown. It's a bug" << str;
         return GenericNetworkManager::PluginNetworkType::Unknown;
     }
 }
 
-QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> GenericNetworkServerInfo::supportedServers(const QString &name) const
+QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> GenericNetworkServerInfo::supportedServers(const QString &name)
 {
     QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> listInfo;
     for (int i = static_cast<int>(GenericNetworkManager::PluginNetworkType::Unknown) + 1;
@@ -216,10 +228,10 @@ QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> Generic
     return listInfo;
 }
 
-GenericNetworkServerInfo::Limitations GenericNetworkServerInfo::limitations(GenericNetworkManager::PluginNetworkType type) const
+GenericNetworkManager::Limitations GenericNetworkServerInfo::limitations(GenericNetworkManager::PluginNetworkType type)
 {
-    GenericNetworkServerInfo::Limitations limits;
-    limits |= GenericNetworkServerInfo::Limitation::None;
+    GenericNetworkManager::Limitations limits;
+    limits |= GenericNetworkManager::Limitation::None;
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
         qCWarning(AUTOGENERATETEXT_GENERICNETWORK_LOG) << "PluginNetworkType is unknown. It's a bug";
@@ -229,23 +241,24 @@ GenericNetworkServerInfo::Limitations GenericNetworkServerInfo::limitations(Gene
     case GenericNetworkManager::PluginNetworkType::OpenAI:
         return limits;
     case GenericNetworkManager::PluginNetworkType::GroqAI:
-        limits |= GenericNetworkServerInfo::Limitation::TextOnly;
+        limits |= GenericNetworkManager::Limitation::TextOnly;
         return limits;
     case GenericNetworkManager::PluginNetworkType::VeniceAI:
-        limits |= GenericNetworkServerInfo::Limitation::NoSystemMessage;
+        limits |= GenericNetworkManager::Limitation::NoSystemMessage;
         return limits;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
-        limits |= GenericNetworkServerInfo::Limitation::NoSystemMessage;
+        limits |= GenericNetworkManager::Limitation::NoSeed;
         return limits;
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return limits;
     }
     return limits;
 }
 
-bool GenericNetworkServerInfo::hasVisionSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
+bool GenericNetworkServerInfo::hasVisionSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -265,12 +278,13 @@ bool GenericNetworkServerInfo::hasVisionSupport(const QString &currentModel, Gen
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return false;
     }
     return false;
 }
 
-bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
+bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type)
 {
     qDebug() << " bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const"
              << currentModel << " type " << static_cast<int>(type);
@@ -298,12 +312,13 @@ bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, Gene
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return false;
     }
     return false;
 }
 
-bool GenericNetworkServerInfo::hasOcrSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
+bool GenericNetworkServerInfo::hasOcrSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -318,12 +333,35 @@ bool GenericNetworkServerInfo::hasOcrSupport(const QString &currentModel, Generi
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return false;
     }
     return false;
 }
 
-bool GenericNetworkServerInfo::hasAudioSupport(const QString &currentMode, GenericNetworkManager::PluginNetworkType type) const
+bool GenericNetworkServerInfo::hasThinkSupport(const QString &currentMode, GenericNetworkManager::PluginNetworkType type)
+{
+    // TODO
+    switch (type) {
+    case GenericNetworkManager::PluginNetworkType::Unknown:
+        qCWarning(AUTOGENERATETEXT_GENERICNETWORK_LOG) << "PluginNetworkType is unknown. It's a bug";
+        return false;
+    case GenericNetworkManager::PluginNetworkType::MistralAI:
+    case GenericNetworkManager::PluginNetworkType::LlamaApi:
+    case GenericNetworkManager::PluginNetworkType::OpenAI:
+    case GenericNetworkManager::PluginNetworkType::GroqAI:
+    case GenericNetworkManager::PluginNetworkType::VeniceAI:
+    case GenericNetworkManager::PluginNetworkType::KimiAI:
+    case GenericNetworkManager::PluginNetworkType::KlusterAI:
+    case GenericNetworkManager::PluginNetworkType::CerebrasAI:
+    case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
+        return false;
+    }
+    return false;
+}
+
+bool GenericNetworkServerInfo::hasAudioSupport(const QString &currentMode, GenericNetworkManager::PluginNetworkType type)
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -338,6 +376,7 @@ bool GenericNetworkServerInfo::hasAudioSupport(const QString &currentMode, Gener
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
+    case GenericNetworkManager::PluginNetworkType::GrokAI:
         return false;
     }
     return false;
