@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,6 +17,7 @@ public:
         QString cudaVisibleDevice;
         QString rocrVisibleDevice;
         QString overrideGfxVersion;
+        QString hipVisibleDevice;
         QString defaultModelPath;
     };
 
@@ -31,5 +32,6 @@ private:
     QLineEdit *const mCudaVisibleDeviceLineEdit;
     QLineEdit *const mRocrVisibleDeviceLineEdit;
     QLineEdit *const mOverrideGfxVersionLineEdit;
+    QLineEdit *const mHipVisibleDeviceLineEdit;
     KUrlRequester *const mDefaultModelPath;
 };
