@@ -6,12 +6,14 @@
 #pragma once
 #include "textautogenerateollama_export.h"
 #include <QWidget>
+class OllamaCommonOverrideParametersWidget;
 class QLineEdit;
-class OllamaComboBoxWidget;
-class OllamaManager;
-class QDoubleSpinBox;
 class QSpinBox;
+class OllamaCommonComboBoxWidget;
+class OllamaManager;
 class OllamaConfigureCustomizeWidget;
+class OllamaCommonKeepAliveParametersWidget;
+class OllamaCommonOptionsWidget;
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateNotWorkingMessageWidget;
@@ -25,6 +27,7 @@ public:
 
     void loadSettings();
     void saveSettings();
+    void restoreToDefaults();
 
 Q_SIGNALS:
     void ollamaProcessOk(bool status);
@@ -33,12 +36,19 @@ Q_SIGNALS:
 private:
     TEXTAUTOGENERATEOLLAMA_NO_EXPORT void fillModels();
     TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotStartOllama();
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void showModelInfo(const QString &modelName);
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void displayModelInfo(const QString &modelStr);
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotOllamaStarted();
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotOllamaFailed(const QString &errorStr);
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotShowOllamaLog();
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void showOllamaVersion();
     QLineEdit *const mName;
-    QLineEdit *const mServerUrl;
-    OllamaComboBoxWidget *const mModelComboBoxWidget;
+    QSpinBox *const mPort;
+    OllamaCommonComboBoxWidget *const mModelComboBoxWidget;
     TextAutoGenerateText::TextAutoGenerateNotWorkingMessageWidget *const mMessageWidget;
-    QDoubleSpinBox *const mTemperature;
-    QSpinBox *const mSeed;
     OllamaManager *const mManager;
     OllamaConfigureCustomizeWidget *const mOllamaConfigureCustomizeWidget;
+    OllamaCommonOverrideParametersWidget *const mOllamaCommonOverrideParametersWidget;
+    OllamaCommonKeepAliveParametersWidget *const mOllamaCommonKeepAliveParametersWidget;
+    OllamaCommonOptionsWidget *const mOllamaCommonOptionsWidget;
 };
