@@ -5,33 +5,22 @@
 */
 
 #pragma once
+#include "ollamacommonsettings.h"
 #include "textautogenerateollama_export.h"
-
 #include <QString>
 #include <QUrl>
 class QDebug;
 class QProcessEnvironment;
 using namespace Qt::Literals::StringLiterals;
-class TEXTAUTOGENERATEOLLAMA_EXPORT OllamaSettings
+class TEXTAUTOGENERATEOLLAMA_EXPORT OllamaSettings : public OllamaCommonSettings
 {
 public:
     OllamaSettings();
-    ~OllamaSettings();
-    [[nodiscard]] int seed() const;
-    void setSeed(int newSeed);
-
-    [[nodiscard]] double temperature() const;
-    void setTemperature(double newTemperature);
-
-    [[nodiscard]] QString currentModel() const;
-    void setCurrentModel(const QString &newCurrentModel);
+    ~OllamaSettings() override;
 
     [[nodiscard]] QUrl serverUrl() const;
     void setServerUrl(const QUrl &newServerUrl);
 
-    [[nodiscard]] QString displayName() const;
-    void setDisplayName(const QString &newName);
-
     [[nodiscard]] QString overrideGfxVersion() const;
     void setOverrideGfxVersion(const QString &newOverrideGfxVersion);
 
@@ -49,16 +38,26 @@ public:
     [[nodiscard]] QString defaultModelPath() const;
     void setDefaultModelPath(const QString &newDefaultModelPath);
 
+    void load(const KConfigGroup &config) override;
+    void save(KConfigGroup &config) override;
+
+    [[nodiscard]] bool expose() const;
+    void setExpose(bool newExpose);
+
+    [[nodiscard]] QString ollamaExpose() const;
+
+    [[nodiscard]] QString hipVisibleDevice() const;
+    void setHipVisibleDevice(const QString &newHipVisibleDevice);
+
 private:
     QString mVulkanSupport;
     QString mOverrideGfxVersion;
     QString mRocrVisibleDevice;
     QString mCudaVisibleDevice;
+    QString mHipVisibleDevice;
     QString mDisplayName;
     QUrl mServerUrl = QUrl(u"http://127.0.0.1:11434"_s);
     QString mDefaultModelPath;
-    QString mCurrentModel;
-    int mSeed = 0;
-    double mTemperature = 0.8;
+    bool mExpose = false;
 };
 TEXTAUTOGENERATEOLLAMA_EXPORT QDebug operator<<(QDebug d, const OllamaSettings &t);
