@@ -1,18 +1,18 @@
 /*
-  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "speechtotextaction.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "textspeechtotext/speechtotextmanager.h"
 using namespace TextSpeechToText;
+using namespace Qt::Literals::StringLiterals;
 SpeechToTextAction::SpeechToTextAction(QObject *parent)
     : QAction{parent}
 {
-    connect(this, &QAction::trigger, this, &SpeechToTextAction::slotClicked);
+    connect(this, &QAction::triggered, this, &SpeechToTextAction::slotClicked);
 }
 
 SpeechToTextAction::~SpeechToTextAction() = default;
